@@ -1,4 +1,10 @@
 # -*- coding: utf-8 -*-
+
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
+from __future__ import unicode_literals
+
 from .client import InfluxDBClient
 from .client import InfluxDBClusterClient
 from .dataframe_client import DataFrameClient
@@ -13,4 +19,4 @@ __all__ = [
 ]
 
 
-__version__ = '2.12.0'
+__version__ = '3.0.0'
