@@ -2,6 +2,11 @@
 """
 DataFrame client for InfluxDB
 """
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
+from __future__ import unicode_literals
+
 import math
 
 import pandas as pd
@@ -85,22 +90,10 @@ class DataFrameClient(InfluxDBClient):
         else:
             return results
 
-    def get_list_series(self, database=None):
-        """
-        Get the list of series, in DataFrame
-
-        """
-        results = super(DataFrameClient, self)\
-            .query("SHOW SERIES", database=database)
-        if len(results):
-            return dict(
-                (key[0], pd.DataFrame(data)) for key, data in results.items()
-            )
-        else:
-            return {}
-
     def _to_dataframe(self, rs):
         result = {}
+        if isinstance(rs, list):
+            return map(self._to_dataframe, rs)
         for key, data in rs.items():
             name, tags = key
             if tags is None:
