@@ -2,6 +2,10 @@
 """
 Python client for InfluxDB
 """
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
+from __future__ import unicode_literals
 
 from functools import wraps
 import json
@@ -54,7 +58,7 @@ class InfluxDBClient(object):
         establish a connection, defaults to None
     :type timeout: int
     :param use_udp: use UDP to connect to InfluxDB, defaults to False
-    :type use_udp: int
+    :type use_udp: bool
     :param udp_port: UDP port to connect to InfluxDB, defaults to 4444
     :type udp_port: int
     :param proxies: HTTP(S) proxy to use for Requests, defaults to {}
@@ -76,7 +80,7 @@ class InfluxDBClient(object):
                  ):
         """Construct a new InfluxDBClient object."""
         self.__host = host
-        self._port = port
+        self.__port = int(port)
         self._username = username
         self._password = password
         self._database = database
@@ -110,7 +114,7 @@ class InfluxDBClient(object):
             'Accept': 'text/plain'
         }
 
-    # _baseurl and _host are properties to allow InfluxDBClusterClient
+    # _baseurl, _host and _port are properties to allow InfluxDBClusterClient
     # to override them with thread-local variables
     @property
     def _baseurl(self):
@@ -126,6 +130,13 @@ class InfluxDBClient(object):
     def _get_host(self):
         return self.__host
 
+    @property
+    def _port(self):
+        return self._get_port()
+
+    def _get_port(self):
+        return self.__port
+
     @staticmethod
     def from_DSN(dsn, **kwargs):
         """Return an instance of :class:`~.InfluxDBClient` from the provided
@@ -454,16 +465,13 @@ localhost:8086/databasename', timeout=5, udp_port=159)
         """
         return list(self.query("SHOW DATABASES").get_points())
 
-    def create_database(self, dbname, if_not_exists=False):
+    def create_database(self, dbname):
         """Create a new database in InfluxDB.
 
         :param dbname: the name of the database to create
         :type dbname: str
         """
-        if if_not_exists:
-            self.query("CREATE DATABASE IF NOT EXISTS \"%s\"" % dbname)
-        else:
-            self.query("CREATE DATABASE \"%s\"" % dbname)
+        self.query("CREATE DATABASE \"%s\"" % dbname)
 
     def drop_database(self, dbname):
         """Drop a database from InfluxDB.
@@ -495,7 +503,7 @@ localhost:8086/databasename', timeout=5, udp_port=159)
         :type default: bool
         """
         query_string = \
-            "CREATE RETENTION POLICY %s ON %s " \
+            "CREATE RETENTION POLICY \"%s\" ON \"%s\" " \
             "DURATION %s REPLICATION %s" % \
             (name, database or self._database, duration, replication)
 
@@ -530,7 +538,7 @@ localhost:8086/databasename', timeout=5, udp_port=159)
             should be set. Otherwise the operation will fail.
         """
         query_string = (
-            "ALTER RETENTION POLICY {0} ON {1}"
+            "ALTER RETENTION POLICY \"{0}\" ON \"{1}\""
         ).format(name, database or self._database)
         if duration:
             query_string += " DURATION {0}".format(duration)
@@ -541,6 +549,20 @@ localhost:8086/databasename', timeout=5, udp_port=159)
 
         self.query(query_string)
 
+    def drop_retention_policy(self, name, database=None):
+        """Drop an existing retention policy for a database.
+
+        :param name: the name of the retention policy to drop
+        :type name: str
+        :param database: the database for which the retention policy is
+            dropped. Defaults to current client's database
+        :type database: str
+        """
+        query_string = (
+            "DROP RETENTION POLICY \"{0}\" ON \"{1}\""
+        ).format(name, database or self._database)
+        self.query(query_string)
+
     def get_list_retention_policies(self, database=None):
         """Get the list of retention policies for a database.
 
@@ -562,39 +584,10 @@ localhost:8086/databasename', timeout=5, udp_port=159)
               u'replicaN': 1}]
             """
         rsp = self.query(
-            "SHOW RETENTION POLICIES ON %s" % (database or self._database)
+            "SHOW RETENTION POLICIES ON \"%s\"" % (database or self._database)
         )
         return list(rsp.get_points())
 
-    def get_list_series(self, database=None):
-        """Get the list of series for a database.
-
-        :param database: the name of the database, defaults to the client's
-            current database
-        :type database: str
-        :returns: all series in the specified database
-        :rtype: list of dictionaries
-
-        :Example:
-
-        >> series = client.get_list_series('my_database')
-        >> series
-        [{'name': u'cpu_usage',
-          'tags': [{u'_id': 1,
-                    u'host': u'server01',
-                    u'region': u'us-west'}]}]
-        """
-        rsp = self.query("SHOW SERIES", database=database)
-        series = []
-        for serie in rsp.items():
-            series.append(
-                {
-                    "name": serie[0][0],
-                    "tags": list(serie[1])
-                }
-            )
-        return series
-
     def get_list_servers(self):
         """Get the list of servers in InfluxDB cluster.
 
@@ -643,13 +636,14 @@ localhost:8086/databasename', timeout=5, udp_port=159)
             privileges or not
         :type admin: boolean
         """
-        text = "CREATE USER {0} WITH PASSWORD '{1}'".format(username, password)
+        text = "CREATE USER \"{0}\" WITH PASSWORD '{1}'".format(username,
+                                                                password)
         if admin:
             text += ' WITH ALL PRIVILEGES'
         self.query(text)
 
     def drop_user(self, username):
-        """Drop an user from InfluxDB.
+        """Drop a user from InfluxDB.
 
         :param username: the username to drop
         :type username: str
@@ -690,8 +684,20 @@ localhost:8086/databasename', timeout=5, udp_port=159)
                                                    for k, v in tags.items()])
         self.query(query_str, database=database)
 
+    def grant_admin_privileges(self, username):
+        """Grant cluster administration privileges to a user.
+
+        :param username: the username to grant privileges to
+        :type username: str
+
+        .. note:: Only a cluster administrator can create/drop databases
+            and manage users.
+        """
+        text = "GRANT ALL PRIVILEGES TO {0}".format(username)
+        self.query(text)
+
     def revoke_admin_privileges(self, username):
-        """Revoke cluster administration privileges from an user.
+        """Revoke cluster administration privileges from a user.
 
         :param username: the username to revoke privileges from
         :type username: str
@@ -703,7 +709,7 @@ localhost:8086/databasename', timeout=5, udp_port=159)
         self.query(text)
 
     def grant_privilege(self, privilege, database, username):
-        """Grant a privilege on a database to an user.
+        """Grant a privilege on a database to a user.
 
         :param privilege: the privilege to grant, one of 'read', 'write'
             or 'all'. The string is case-insensitive
@@ -719,7 +725,7 @@ localhost:8086/databasename', timeout=5, udp_port=159)
         self.query(text)
 
     def revoke_privilege(self, privilege, database, username):
-        """Revoke a privilege on a database from an user.
+        """Revoke a privilege on a database from a user.
 
         :param privilege: the privilege to revoke, one of 'read', 'write'
             or 'all'. The string is case-insensitive
@@ -734,6 +740,28 @@ localhost:8086/databasename', timeout=5, udp_port=159)
                                                    username)
         self.query(text)
 
+    def get_list_privileges(self, username):
+        """Get the list of all privileges granted to given user.
+
+        :param username: the username to get privileges of
+        :type username: str
+
+        :returns: all privileges granted to given user
+        :rtype: list of dictionaries
+
+        :Example:
+
+        ::
+
+            >> privileges = client.get_list_privileges('user1')
+            >> privileges
+            [{u'privilege': u'WRITE', u'database': u'db1'},
+             {u'privilege': u'ALL PRIVILEGES', u'database': u'db2'},
+             {u'privilege': u'NO PRIVILEGES', u'database': u'db3'}]
+        """
+        text = "SHOW GRANTS FOR {0}".format(username)
+        return list(self.query(text).get_points())
+
     def send_packet(self, packet):
         """Send an UDP packet.
 
@@ -806,6 +834,7 @@ class InfluxDBClusterClient(object):
             setattr(self, method, self._make_func(orig_attr))
 
         self._client._get_host = self._get_host
+        self._client._get_port = self._get_port
         self._client._get_baseurl = self._get_baseurl
         self._update_client_host(self.hosts[0])
 
@@ -856,6 +885,9 @@ class InfluxDBClusterClient(object):
     def _get_host(self):
         return self._thread_local.host
 
+    def _get_port(self):
+        return self._thread_local.port
+
     def _make_func(self, orig_func):
 
         @wraps(orig_func)
@@ -881,6 +913,8 @@ class InfluxDBClusterClient(object):
                 except InfluxDBClientError as e:
                     # Errors caused by user's requests, re-raise
                     raise e
+                except ValueError as e:
+                    raise e
                 except Exception as e:
                     # Errors that might caused by server failure, try another
                     bad_host = True
