@@ -2,6 +2,10 @@
 """
 DataFrame client for InfluxDB
 """
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
+from __future__ import unicode_literals
 
 __all__ = ['DataFrameClient']
 
