@@ -14,6 +14,11 @@ detected by this module.
 See client_test_with_server.py for tests against a running server instance.
 
 """
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
+from __future__ import unicode_literals
+
 import json
 import requests
 import requests.exceptions
@@ -25,11 +30,7 @@ from nose.tools import raises
 from mock import patch
 import warnings
 import mock
-import sys
-if sys.version_info < (2, 7):
-    import unittest2 as unittest
-else:
-    import unittest
+import unittest
 
 from influxdb import InfluxDBClient, InfluxDBClusterClient
 from influxdb.client import InfluxDBServerError
@@ -417,19 +418,6 @@ class TestInfluxDBClient(unittest.TestCase):
                 'create database "new_db"'
             )
 
-    def test_create_database_with_exist_check(self):
-        with requests_mock.Mocker() as m:
-            m.register_uri(
-                requests_mock.GET,
-                "http://localhost:8086/query",
-                text='{"results":[{}]}'
-            )
-            self.cli.create_database('new_db', if_not_exists=True)
-            self.assertEqual(
-                m.last_request.qs['q'][0],
-                'create database if not exists "new_db"'
-            )
-
     def test_create_numeric_named_database(self):
         with requests_mock.Mocker() as m:
             m.register_uri(
@@ -474,12 +462,6 @@ class TestInfluxDBClient(unittest.TestCase):
                 'drop database "123"'
             )
 
-    @raises(Exception)
-    def test_drop_database_fails(self):
-        cli = InfluxDBClient('host', 8086, 'username', 'password', 'db')
-        with _mocked_session(cli, 'delete', 401):
-            cli.drop_database('old_db')
-
     def test_get_list_database(self):
         data = {'results': [
             {'series': [
@@ -535,27 +517,6 @@ class TestInfluxDBClient(unittest.TestCase):
         with _mocked_session(cli, 'get', 401):
             cli.get_list_servers()
 
-    def test_get_list_series(self):
-        example_response = \
-            '{"results": [{"series": [{"name": "cpu_load_short", "columns": ' \
-            '["_id", "host", "region"], "values": ' \
-            '[[1, "server01", "us-west"]]}]}]}'
-
-        with requests_mock.Mocker() as m:
-            m.register_uri(
-                requests_mock.GET,
-                "http://localhost:8086/query",
-                text=example_response
-            )
-
-            self.assertListEqual(
-                self.cli.get_list_series(),
-                [{'name': 'cpu_load_short',
-                  'tags': [
-                      {'host': 'server01', '_id': 1, 'region': 'us-west'}
-                  ]}]
-            )
-
     def test_create_retention_policy_default(self):
         example_response = '{"results":[{}]}'
 
@@ -571,8 +532,8 @@ class TestInfluxDBClient(unittest.TestCase):
 
             self.assertEqual(
                 m.last_request.qs['q'][0],
-                'create retention policy somename on '
-                'db duration 1d replication 4 default'
+                'create retention policy "somename" on '
+                '"db" duration 1d replication 4 default'
             )
 
     def test_create_retention_policy(self):
@@ -590,8 +551,8 @@ class TestInfluxDBClient(unittest.TestCase):
 
             self.assertEqual(
                 m.last_request.qs['q'][0],
-                'create retention policy somename on '
-                'db duration 1d replication 4'
+                'create retention policy "somename" on '
+                '"db" duration 1d replication 4'
             )
 
     def test_alter_retention_policy(self):
@@ -608,14 +569,14 @@ class TestInfluxDBClient(unittest.TestCase):
                                             duration='4d')
             self.assertEqual(
                 m.last_request.qs['q'][0],
-                'alter retention policy somename on db duration 4d'
+                'alter retention policy "somename" on "db" duration 4d'
             )
             # Test alter replication
             self.cli.alter_retention_policy('somename', 'db',
                                             replication=4)
             self.assertEqual(
                 m.last_request.qs['q'][0],
-                'alter retention policy somename on db replication 4'
+                'alter retention policy "somename" on "db" replication 4'
             )
 
             # Test alter default
@@ -623,7 +584,7 @@ class TestInfluxDBClient(unittest.TestCase):
                                             default=True)
             self.assertEqual(
                 m.last_request.qs['q'][0],
-                'alter retention policy somename on db default'
+                'alter retention policy "somename" on "db" default'
             )
 
     @raises(Exception)
@@ -632,6 +593,27 @@ class TestInfluxDBClient(unittest.TestCase):
         with _mocked_session(cli, 'get', 400):
             self.cli.alter_retention_policy('somename', 'db')
 
+    def test_drop_retention_policy(self):
+        example_response = '{"results":[{}]}'
+
+        with requests_mock.Mocker() as m:
+            m.register_uri(
+                requests_mock.GET,
+                "http://localhost:8086/query",
+                text=example_response
+            )
+            self.cli.drop_retention_policy('somename', 'db')
+            self.assertEqual(
+                m.last_request.qs['q'][0],
+                'drop retention policy "somename" on "db"'
+            )
+
+    @raises(Exception)
+    def test_drop_retention_policy_fails(self):
+        cli = InfluxDBClient('host', 8086, 'username', 'password')
+        with _mocked_session(cli, 'delete', 401):
+            cli.drop_retention_policy('default', 'db')
+
     def test_get_list_retention_policies(self):
         example_response = \
             '{"results": [{"series": [{"values": [["fsfdsdf", "24h0m0s", 2]],'\
@@ -728,6 +710,28 @@ class TestInfluxDBClient(unittest.TestCase):
 
             self.assertListEqual(self.cli.get_list_users(), [])
 
+    def test_grant_admin_privileges(self):
+        example_response = '{"results":[{}]}'
+
+        with requests_mock.Mocker() as m:
+            m.register_uri(
+                requests_mock.GET,
+                "http://localhost:8086/query",
+                text=example_response
+            )
+            self.cli.grant_admin_privileges('test')
+
+            self.assertEqual(
+                m.last_request.qs['q'][0],
+                'grant all privileges to test'
+            )
+
+    @raises(Exception)
+    def test_grant_admin_privileges_invalid(self):
+        cli = InfluxDBClient('host', 8086, 'username', 'password')
+        with _mocked_session(cli, 'get', 400):
+            self.cli.grant_admin_privileges('')
+
     def test_revoke_admin_privileges(self):
         example_response = '{"results":[{}]}'
 
@@ -794,6 +798,35 @@ class TestInfluxDBClient(unittest.TestCase):
         with _mocked_session(cli, 'get', 400):
             self.cli.revoke_privilege('', 'testdb', 'test')
 
+    def test_get_list_privileges(self):
+        data = {'results': [
+            {'series': [
+                {'columns': ['database', 'privilege'],
+                 'values': [
+                     ['db1', 'READ'],
+                     ['db2', 'ALL PRIVILEGES'],
+                     ['db3', 'NO PRIVILEGES']]}
+            ]}
+        ]}
+
+        with _mocked_session(self.cli, 'get', 200, json.dumps(data)):
+            self.assertListEqual(
+                self.cli.get_list_privileges('test'),
+                [{'database': 'db1', 'privilege': 'READ'},
+                 {'database': 'db2', 'privilege': 'ALL PRIVILEGES'},
+                 {'database': 'db3', 'privilege': 'NO PRIVILEGES'}]
+            )
+
+    @raises(Exception)
+    def test_get_list_privileges_fails(self):
+        cli = InfluxDBClient('host', 8086, 'username', 'password')
+        with _mocked_session(cli, 'get', 401):
+            cli.get_list_privileges('test')
+
+    def test_invalid_port_fails(self):
+        with self.assertRaises(ValueError):
+            InfluxDBClient('host', '80/redir', 'username', 'password')
+
 
 class FakeClient(InfluxDBClient):
 
