@@ -2,13 +2,14 @@
 """
 unit tests for misc module
 """
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
+from __future__ import unicode_literals
+
 from .client_test import _mocked_session
 
-import sys
-if sys.version_info < (2, 7):
-    import unittest2 as unittest
-else:
-    import unittest
+import unittest
 import json
 import requests_mock
 from nose.tools import raises
@@ -244,55 +245,62 @@ class TestDataFrameClient(unittest.TestCase):
             for k in expected:
                 assert_frame_equal(expected[k], result[k])
 
+    def test_multiquery_into_dataframe(self):
+        data = {
+            "results": [
+                {
+                    "series": [
+                        {
+                            "name": "cpu_load_short",
+                            "columns": ["time", "value"],
+                            "values": [
+                                ["2015-01-29T21:55:43.702900257Z", 0.55],
+                                ["2015-01-29T21:55:43.702900257Z", 23422],
+                                ["2015-06-11T20:46:02Z", 0.64]
+                            ]
+                        }
+                    ]
+                }, {
+                    "series": [
+                        {
+                            "name": "cpu_load_short",
+                            "columns": ["time", "count"],
+                            "values": [
+                                ["1970-01-01T00:00:00Z", 3]
+                            ]
+                        }
+                    ]
+                }
+            ]
+        }
+
+        pd1 = pd.DataFrame(
+            [[0.55], [23422.0], [0.64]], columns=['value'],
+            index=pd.to_datetime([
+                "2015-01-29 21:55:43.702900257+0000",
+                "2015-01-29 21:55:43.702900257+0000",
+                "2015-06-11 20:46:02+0000"])).tz_localize('UTC')
+        pd2 = pd.DataFrame(
+            [[3]], columns=['count'],
+            index=pd.to_datetime(["1970-01-01 00:00:00+00:00"]))\
+            .tz_localize('UTC')
+        expected = [{'cpu_load_short': pd1}, {'cpu_load_short': pd2}]
+
+        cli = DataFrameClient('host', 8086, 'username', 'password', 'db')
+        iql = "SELECT value FROM cpu_load_short WHERE region='us-west';"\
+            "SELECT count(value) FROM cpu_load_short WHERE region='us-west'"
+        with _mocked_session(cli, 'GET', 200, data):
+            result = cli.query(iql)
+            for r, e in zip(result, expected):
+                for k in e:
+                    assert_frame_equal(e[k], r[k])
+
     def test_query_with_empty_result(self):
         cli = DataFrameClient('host', 8086, 'username', 'password', 'db')
         with _mocked_session(cli, 'GET', 200, {"results": [{}]}):
             result = cli.query('select column_one from foo;')
             self.assertEqual(result, {})
 
-    def test_list_series(self):
-        response = {
-            'results': [
-                {'series': [
-                    {
-                        'columns': ['host'],
-                        'measurement': 'cpu',
-                        'values': [
-                            ['server01']]
-                    },
-                    {
-                        'columns': [
-                            'host',
-                            'region'
-                        ],
-                        'measurement': 'network',
-                        'values': [
-                            [
-                                'server01',
-                                'us-west'
-                            ],
-                            [
-                                'server01',
-                                'us-east'
-                            ]
-                        ]
-                    }
-                ]}
-            ]
-        }
-
-        expected = {
-            'cpu': pd.DataFrame([['server01']], columns=['host']),
-            'network': pd.DataFrame(
-                [['server01', 'us-west'], ['server01', 'us-east']],
-                columns=['host', 'region'])}
-
-        cli = DataFrameClient('host', 8086, 'username', 'password', 'db')
-        with _mocked_session(cli, 'GET', 200, response):
-            series = cli.get_list_series()
-            assert_frame_equal(series['cpu'], expected['cpu'])
-            assert_frame_equal(series['network'], expected['network'])
-
     def test_get_list_database(self):
         data = {'results': [
             {'series': [
