@@ -9,17 +9,15 @@ This basically duplicates what's in client_test.py
  but without mocking around every call.
 
 """
-
+from __future__ import absolute_import
+from __future__ import division
 from __future__ import print_function
+from __future__ import unicode_literals
 
 from functools import partial
 import os
 import time
-import sys
-if sys.version_info < (2, 7):
-    import unittest2 as unittest
-else:
-    import unittest
+import unittest
 import warnings
 
 # By default, raise exceptions on warnings
@@ -135,38 +133,11 @@ class SimpleTests(SingleTestCaseWithServerMixin,
             [{'name': 'new_db_1'}, {'name': 'new_db_2'}]
         )
 
-    def test_create_database_twice_if_not_exist(self):
-        self.assertIsNone(self.cli.create_database('new_db'))
-        self.assertIsNone(
-            self.cli.create_database('new_db', if_not_exists=True))
-
-    def test_create_database_twice_fails(self):
-        self.assertIsNone(self.cli.create_database('new_db'))
-        with self.assertRaises(InfluxDBClientError) as ctx:
-            self.cli.create_database('new_db')
-        self.assertEqual('database already exists',
-                         ctx.exception.content)
-
-    def test_get_list_series_empty(self):
-        rsp = self.cli.get_list_series()
-        self.assertEqual([], rsp)
-
-    @unittest.skip("Broken as of 0.9.0")
-    def test_get_list_series_empty_DF(self):
-        rsp = self.cliDF.get_list_series()
-        self.assertEqual({}, rsp)
-
     def test_drop_database(self):
         self.test_create_database()
         self.assertIsNone(self.cli.drop_database('new_db_1'))
         self.assertEqual([{'name': 'new_db_2'}], self.cli.get_list_database())
 
-    def test_drop_database_fails(self):
-        with self.assertRaises(InfluxDBClientError) as ctx:
-            self.cli.drop_database('db')
-        self.assertIn('database not found: db',
-                      ctx.exception.content)
-
     def test_query_fail(self):
         with self.assertRaises(InfluxDBClientError) as ctx:
             self.cli.query('select column_one from foo')
@@ -212,19 +183,7 @@ class SimpleTests(SingleTestCaseWithServerMixin,
     def test_create_user_blank_username(self):
         with self.assertRaises(InfluxDBClientError) as ctx:
             self.cli.create_user('', 'secret_password')
-        self.assertEqual(400, ctx.exception.code)
-        self.assertIn('{"error":"error parsing query: '
-                      'found WITH, expected identifier',
-                      ctx.exception.content)
-        rsp = list(self.cli.query("SHOW USERS")['results'])
-        self.assertEqual(rsp, [])
-
-    def test_create_user_invalid_username(self):
-        with self.assertRaises(InfluxDBClientError) as ctx:
-            self.cli.create_user('very invalid', 'secret_password')
-        self.assertEqual(400, ctx.exception.code)
-        self.assertIn('{"error":"error parsing query: '
-                      'found invalid, expected WITH',
+        self.assertIn('username required',
                       ctx.exception.content)
         rsp = list(self.cli.query("SHOW USERS")['results'])
         self.assertEqual(rsp, [])
@@ -295,6 +254,10 @@ class SimpleTests(SingleTestCaseWithServerMixin,
         self.assertIn('{"error":"error parsing query: ',
                       ctx.exception.content)
 
+    def test_invalid_port_fails(self):
+        with self.assertRaises(ValueError):
+            InfluxDBClient('host', '80/redir', 'username', 'password')
+
 
 @skipServerTests
 class CommonTests(ManyTestCasesWithServerMixin,
@@ -337,8 +300,12 @@ class CommonTests(ManyTestCasesWithServerMixin,
 
         self.assertEqual(
             list(rsp),
-            [[{'value': 0.64, 'time': '2009-11-10T23:00:00Z',
-               "host": "server01", "region": "us-west"}]]
+            [[
+                {'value': 0.64,
+                 'time': '2009-11-10T23:00:00Z',
+                 "host": "server01",
+                 "region": "us-west"}
+            ]]
         )
 
         rsp2 = list(rsp.get_points())
@@ -347,8 +314,10 @@ class CommonTests(ManyTestCasesWithServerMixin,
 
         self.assertEqual(
             pt,
-            {'time': '2009-11-10T23:00:00Z', 'value': 0.64,
-             "host": "server01", "region": "us-west"}
+            {'time': '2009-11-10T23:00:00Z',
+             'value': 0.64,
+             "host": "server01",
+             "region": "us-west"}
         )
 
     @unittest.skip("Broken as of 0.9.0")
@@ -378,8 +347,12 @@ class CommonTests(ManyTestCasesWithServerMixin,
         lrsp = list(rsp)
 
         self.assertEqual(
-            [[{'value': 0.64, 'time': '2009-11-10T23:00:00Z',
-               "host": "server01", "region": "us-west"}]],
+            [[
+                {'value': 0.64,
+                 'time': '2009-11-10T23:00:00Z',
+                 "host": "server01",
+                 "region": "us-west"}
+            ]],
             lrsp
         )
 
@@ -387,8 +360,12 @@ class CommonTests(ManyTestCasesWithServerMixin,
 
         self.assertEqual(
             rsp,
-            [[{'value': 33, 'time': '2009-11-10T23:01:35Z',
-               "host": "server01", "region": "us-west"}]]
+            [[
+                {'value': 33,
+                 'time': '2009-11-10T23:01:35Z',
+                 "host": "server01",
+                 "region": "us-west"}
+            ]]
         )
 
     @unittest.skip("Broken as of 0.9.0")
@@ -461,44 +438,10 @@ class CommonTests(ManyTestCasesWithServerMixin,
         del example_object
         # TODO ?
 
-    def test_get_list_series_and_delete(self):
-        self.cli.write_points(dummy_point)
-        rsp = self.cli.get_list_series()
-        self.assertEqual(
-            [
-                {'name': 'cpu_load_short',
-                 'tags': [
-                     {'host': 'server01',
-                      'region': 'us-west',
-                      '_key':
-                          'cpu_load_short,host=server01,region=us-west'}]}
-            ],
-            rsp
-        )
-
     def test_delete_series_invalid(self):
         with self.assertRaises(InfluxDBClientError):
             self.cli.delete_series()
 
-    def test_delete_series(self):
-        self.assertEqual(len(self.cli.get_list_series()), 0)
-        self.cli.write_points(dummy_points)
-        self.assertEqual(len(self.cli.get_list_series()), 2)
-        self.cli.delete_series(measurement='cpu_load_short')
-        self.assertEqual(len(self.cli.get_list_series()), 1)
-        self.cli.delete_series(tags={'region': 'us-west'})
-        self.assertEqual(len(self.cli.get_list_series()), 0)
-
-    @unittest.skip("Broken as of 0.9.0")
-    def test_get_list_series_DF(self):
-        self.cli.write_points(dummy_point)
-        rsp = self.cliDF.get_list_series()
-
-        expected = pd.DataFrame(
-            [[1, 'server01', 'us-west']],
-            columns=['_id', 'host', 'region'])
-        assert_frame_equal(rsp['cpu_load_short'], expected)
-
     def test_default_retention_policy(self):
         rsp = self.cli.get_list_retention_policies()
         self.assertEqual(
@@ -506,6 +449,7 @@ class CommonTests(ManyTestCasesWithServerMixin,
                 {'name': 'default',
                  'duration': '0',
                  'replicaN': 1,
+                 'shardGroupDuration': u'168h0m0s',
                  'default': True}
             ],
             rsp
@@ -521,14 +465,17 @@ class CommonTests(ManyTestCasesWithServerMixin,
                 {'duration': '0',
                  'default': False,
                  'replicaN': 1,
+                 'shardGroupDuration': u'168h0m0s',
                  'name': 'default'},
                 {'duration': '24h0m0s',
                  'default': True,
                  'replicaN': 1,
+                 'shardGroupDuration': u'1h0m0s',
                  'name': 'somename'},
                 {'duration': '48h0m0s',
                  'default': False,
                  'replicaN': 1,
+                 'shardGroupDuration': u'24h0m0s',
                  'name': 'another'}
             ],
             rsp
@@ -538,10 +485,18 @@ class CommonTests(ManyTestCasesWithServerMixin,
         self.cli.create_retention_policy('somename', '1d', 1)
         rsp = self.cli.get_list_retention_policies()
         self.assertEqual(
-            [{'duration': '0', 'default': True,
-              'replicaN': 1, 'name': 'default'},
-             {'duration': '24h0m0s', 'default': False,
-              'replicaN': 1, 'name': 'somename'}],
+            [
+                {'duration': '0',
+                 'default': True,
+                 'replicaN': 1,
+                 'shardGroupDuration': u'168h0m0s',
+                 'name': 'default'},
+                {'duration': '24h0m0s',
+                 'default': False,
+                 'replicaN': 1,
+                 'shardGroupDuration': u'1h0m0s',
+                 'name': 'somename'}
+            ],
             rsp
         )
 
@@ -553,10 +508,18 @@ class CommonTests(ManyTestCasesWithServerMixin,
                                         duration='4d')
         rsp = self.cli.get_list_retention_policies()
         self.assertEqual(
-            [{'duration': '0', 'default': True,
-              'replicaN': 1, 'name': 'default'},
-             {'duration': '96h0m0s', 'default': False,
-              'replicaN': 1, 'name': 'somename'}],
+            [
+                {'duration': '0',
+                 'default': True,
+                 'replicaN': 1,
+                 'shardGroupDuration': u'168h0m0s',
+                 'name': 'default'},
+                {'duration': '96h0m0s',
+                 'default': False,
+                 'replicaN': 1,
+                 'shardGroupDuration': u'24h0m0s',
+                 'name': 'somename'}
+            ],
             rsp
         )
 
@@ -565,10 +528,18 @@ class CommonTests(ManyTestCasesWithServerMixin,
                                         replication=4)
         rsp = self.cli.get_list_retention_policies()
         self.assertEqual(
-            [{'duration': '0', 'default': True,
-              'replicaN': 1, 'name': 'default'},
-             {'duration': '96h0m0s', 'default': False,
-              'replicaN': 4, 'name': 'somename'}],
+            [
+                {'duration': '0',
+                 'default': True,
+                 'replicaN': 1,
+                 'shardGroupDuration': u'168h0m0s',
+                 'name': 'default'},
+                {'duration': '96h0m0s',
+                 'default': False,
+                 'replicaN': 4,
+                 'shardGroupDuration': u'24h0m0s',
+                 'name': 'somename'}
+            ],
             rsp
         )
 
@@ -577,10 +548,18 @@ class CommonTests(ManyTestCasesWithServerMixin,
                                         default=True)
         rsp = self.cli.get_list_retention_policies()
         self.assertEqual(
-            [{'duration': '0', 'default': False,
-              'replicaN': 1, 'name': 'default'},
-             {'duration': '96h0m0s', 'default': True,
-              'replicaN': 4, 'name': 'somename'}],
+            [
+                {'duration': '0',
+                 'default': False,
+                 'replicaN': 1,
+                 'shardGroupDuration': u'168h0m0s',
+                 'name': 'default'},
+                {'duration': '96h0m0s',
+                 'default': True,
+                 'replicaN': 4,
+                 'shardGroupDuration': u'24h0m0s',
+                 'name': 'somename'}
+            ],
             rsp
         )
 
@@ -593,10 +572,35 @@ class CommonTests(ManyTestCasesWithServerMixin,
                       ctx.exception.content)
         rsp = self.cli.get_list_retention_policies()
         self.assertEqual(
-            [{'duration': '0', 'default': True,
-              'replicaN': 1, 'name': 'default'},
-             {'duration': '24h0m0s', 'default': False,
-              'replicaN': 1, 'name': 'somename'}],
+            [
+                {'duration': '0',
+                 'default': True,
+                 'replicaN': 1,
+                 'shardGroupDuration': u'168h0m0s',
+                 'name': 'default'},
+                {'duration': '24h0m0s',
+                 'default': False,
+                 'replicaN': 1,
+                 'shardGroupDuration': u'1h0m0s',
+                 'name': 'somename'}
+            ],
+            rsp
+        )
+
+    def test_drop_retention_policy(self):
+        self.cli.create_retention_policy('somename', '1d', 1)
+
+        # Test drop retention
+        self.cli.drop_retention_policy('somename', 'db')
+        rsp = self.cli.get_list_retention_policies()
+        self.assertEqual(
+            [
+                {'duration': '0',
+                 'default': True,
+                 'replicaN': 1,
+                 'shardGroupDuration': u'168h0m0s',
+                 'name': 'default'}
+            ],
             rsp
         )
 
@@ -691,7 +695,11 @@ class UdpTests(ManyTestCasesWithServerMixin,
 
         self.assertEqual(
             # this is dummy_points :
-            [{'value': 0.64, 'time': '2009-11-10T23:00:00Z',
-              "host": "server01", "region": "us-west"}],
+            [
+                {'value': 0.64,
+                 'time': '2009-11-10T23:00:00Z',
+                 "host": "server01",
+                 "region": "us-west"}
+            ],
             list(rsp['cpu_load_short'])
         )
