@@ -1,10 +1,11 @@
 # -*- coding: utf-8 -*-
 
-import sys
-if sys.version_info < (2, 7):
-    import unittest2 as unittest
-else:
-    import unittest
+from __future__ import absolute_import
+from __future__ import division
+from __future__ import print_function
+from __future__ import unicode_literals
+
+import unittest
 
 from influxdb import line_protocol
 
@@ -55,3 +56,23 @@ class TestLineProtocol(unittest.TestCase):
             line_protocol.make_lines(data),
             'm1 multi_line="line1\\nline1\\nline3"\n'
         )
+
+    def test_make_lines_unicode(self):
+        data = {
+            "tags": {
+                "unicode_tag": "\'Привет!\'"  # Hello! in Russian
+            },
+            "points": [
+                {
+                    "measurement": "test",
+                    "fields": {
+                        "unicode_val": "Привет!",  # Hello! in Russian
+                    }
+                }
+            ]
+        }
+
+        self.assertEqual(
+            line_protocol.make_lines(data),
+            'test,unicode_tag=\'Привет!\' unicode_val="Привет!"\n'
+        )
